====================
BEMServer API client
====================

.. image:: https://img.shields.io/pypi/v/bemserver-api-client.svg
    :target: https://pypi.org/project/bemserver-api-client/
    :alt: Latest version

.. image:: https://img.shields.io/pypi/pyversions/bemserver-api-client.svg
    :target: https://pypi.org/project/bemserver-api-client/
    :alt: Python versions

.. image:: https://github.com/BEMServer/bemserver-api-client/actions/workflows/build-release.yaml/badge.svg
    :target: https://github.com/bemserver/bemserver-api-client/actions?query=workflow%3Abuild
    :alt: Build status

.. image:: https://codecov.io/gh/BEMServer/bemserver-api-client/branch/main/graph/badge.svg?token=FA5TO5HUKP
    :target: https://codecov.io/gh/bemserver/bemserver-api-client
    :alt: Code coverage


BEMServer is a free Building Energy Management software platform.

Its purpose is to store data collected in buildings and produce useful information such as performance indicators or alerts.


This package is a client for `BEMServer API <https://github.com/BEMServer/bemserver-api>`_, based on `requests <https://pypi.org/project/requests/>`_.
